@@ -41,6 +41,7 @@ from google.api_core.page_iterator import HTTPIterator
 import google.cloud._helpers
 from google.cloud.bigquery import _helpers
 from google.cloud.bigquery import _pandas_helpers
+from google.cloud.bigquery.exceptions import LegacyBigQueryStorageError
 from google.cloud.bigquery.schema import _build_schema_resource
 from google.cloud.bigquery.schema import _parse_schema_resource
 from google.cloud.bigquery.schema import _to_schema_fields
@@ -1519,6 +1520,17 @@ class RowIterator(HTTPIterator):
             )
             return False
 
+        try:
+            from google.cloud import bigquery_storage  # noqa: F401
+        except ImportError:
+            return False
+
+        try:
+            _helpers._verify_bq_storage_version()
+        except LegacyBigQueryStorageError as exc:
+            warnings.warn(str(exc))
+            return False
+
         return True
 
     def _get_next_page_response(self):
@@ -1655,7 +1667,7 @@ class RowIterator(HTTPIterator):
 
         owns_bqstorage_client = False
         if not bqstorage_client and create_bqstorage_client:
-            bqstorage_client = self.client._create_bqstorage_client()
+            bqstorage_client = self.client._ensure_bqstorage_client()
             owns_bqstorage_client = bqstorage_client is not None
 
         try:
