@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,7 +26,7 @@ from .types.model_reference import ModelReference
 from .types.standard_sql import StandardSqlDataType
 from .types.standard_sql import StandardSqlField
 from .types.standard_sql import StandardSqlStructType
-
+from .types.table_reference import TableReference
 
 __all__ = (
     "DeleteModelRequest",
@@ -41,4 +40,5 @@ __all__ = (
     "StandardSqlDataType",
     "StandardSqlField",
     "StandardSqlStructType",
+    "TableReference",
 )
